@@ -55,7 +55,7 @@ int opmetalist_add(struct opmetalist *, struct opmeta *);
 struct opmetalist *opmetalist_merge(struct opmetalist *o, const struct opmetalist *p);
 struct opmetalist *opmetalist_join(struct opmetalist *, struct opmetalist *);
 void opmeta_fixup(struct opmeta *, int, opmeta_fixup_ptr);
-struct opmetalist *opmetalist_new();
+struct opmetalist *opmetalist_new(void);
 struct oplist *opmetalist_resolve(struct opmetalist *, const opmeta_fixup_ptr[]);
 void opmetalist_free(struct opmetalist *);
 
