@@ -1,6 +1,13 @@
-#include <rpc/rpc.h>
-#include <rpc/pmap_clnt.h>
+#include "config.h"
 
+#ifdef HAVE_RPC_RPC_H
+# include <rpc/rpc.h>
+#endif
+#ifdef HAVE_RPC_PMAP_CLNT_H
+# include <rpc/pmap_clnt.h>
+#endif
+
+#include <stdlib.h>
 #include "data.h"
 #include "error.h"
 #include "parse.h"
@@ -10,7 +17,7 @@ void rlp_cleanup(struct rl_cleanup *rlc) {
 	struct numlist *nl;
 	struct rlc_unrpc *rlcu;
 	struct rl_cleanup *next;
-	
+
 	do {
 		switch(rlc->type) {
 			case RLC_UNRPC:
