@@ -38,7 +38,7 @@ struct service {
 	int family;
 	int socktype;
 	int proto;
-	char *protoname;
+	const char *protoname;
 	int backlog;
 	int limit;
 	int wait;
