@@ -6,8 +6,8 @@
 #include <stdlib.h>
 
 #include "error.h"
+#include "rlinetd.h"
 
-extern int rl_debug;
 static void rl_log(int, const char *, int, const char *, va_list);
 
 void rl_note(const char * fmt, ...) {
